import * as bingo_stratum from 'bingo-stratum';
import * as zod from 'zod';

declare const presetEverything: bingo_stratum.Preset<{
    access: zod.ZodUnion<[zod.ZodLiteral<"public">, zod.ZodLiteral<"restricted">]>;
    author: zod.ZodOptional<zod.ZodString>;
    bin: zod.ZodOptional<zod.ZodUnion<[zod.ZodString, zod.ZodRecord<zod.ZodString, zod.ZodString>]>>;
    contributors: zod.ZodOptional<zod.ZodArray<zod.ZodObject<{
        avatar_url: zod.ZodString;
        contributions: zod.ZodArray<zod.ZodString, "many">;
        login: zod.ZodString;
        name: zod.ZodString;
        profile: zod.ZodString;
    }, "strip", zod.ZodTypeAny, {
        avatar_url: string;
        contributions: string[];
        login: string;
        name: string;
        profile: string;
    }, {
        avatar_url: string;
        contributions: string[];
        login: string;
        name: string;
        profile: string;
    }>, "many">>;
    description: zod.ZodDefault<zod.ZodString>;
    directory: zod.ZodString;
    documentation: zod.ZodObject<{
        development: zod.ZodOptional<zod.ZodString>;
        readme: zod.ZodObject<{
            additional: zod.ZodOptional<zod.ZodString>;
            explainer: zod.ZodOptional<zod.ZodString>;
            footnotes: zod.ZodOptional<zod.ZodString>;
            usage: zod.ZodString;
        }, "strip", zod.ZodTypeAny, {
            usage: string;
            additional?: string | undefined;
            explainer?: string | undefined;
            footnotes?: string | undefined;
        }, {
            usage: string;
            additional?: string | undefined;
            explainer?: string | undefined;
            footnotes?: string | undefined;
        }>;
    }, "strip", zod.ZodTypeAny, {
        readme: {
            usage: string;
            additional?: string | undefined;
            explainer?: string | undefined;
            footnotes?: string | undefined;
        };
        development?: string | undefined;
    }, {
        readme: {
            usage: string;
            additional?: string | undefined;
            explainer?: string | undefined;
            footnotes?: string | undefined;
        };
        development?: string | undefined;
    }>;
    email: zod.ZodEffects<zod.ZodUnion<[zod.ZodString, zod.ZodObject<{
        github: zod.ZodString;
        npm: zod.ZodString;
    }, "strip", zod.ZodTypeAny, {
        github: string;
        npm: string;
    }, {
        github: string;
        npm: string;
    }>]>, {
        github: string;
        npm: string;
    }, string | {
        github: string;
        npm: string;
    }>;
    emoji: zod.ZodOptional<zod.ZodString>;
    existingLabels: zod.ZodOptional<zod.ZodArray<zod.ZodObject<{
        color: zod.ZodString;
        description: zod.ZodString;
        name: zod.ZodString;
    }, "strip", zod.ZodTypeAny, {
        name: string;
        description: string;
        color: string;
    }, {
        name: string;
        description: string;
        color: string;
    }>, "many">>;
    funding: zod.ZodOptional<zod.ZodString>;
    guide: zod.ZodOptional<zod.ZodObject<{
        href: zod.ZodString;
        title: zod.ZodString;
    }, "strip", zod.ZodTypeAny, {
        href: string;
        title: string;
    }, {
        href: string;
        title: string;
    }>>;
    keywords: zod.ZodOptional<zod.ZodArray<zod.ZodString, "many">>;
    logo: zod.ZodOptional<zod.ZodObject<{
        alt: zod.ZodString;
        height: zod.ZodOptional<zod.ZodNumber>;
        src: zod.ZodString;
        width: zod.ZodOptional<zod.ZodNumber>;
    }, "strip", zod.ZodTypeAny, {
        alt: string;
        src: string;
        height?: number | undefined;
        width?: number | undefined;
    }, {
        alt: string;
        src: string;
        height?: number | undefined;
        width?: number | undefined;
    }>>;
    node: zod.ZodObject<{
        minimum: zod.ZodString;
        pinned: zod.ZodOptional<zod.ZodString>;
    }, "strip", zod.ZodTypeAny, {
        minimum: string;
        pinned?: string | undefined;
    }, {
        minimum: string;
        pinned?: string | undefined;
    }>;
    owner: zod.ZodString;
    packageData: zod.ZodOptional<zod.ZodObject<{
        dependencies: zod.ZodOptional<zod.ZodRecord<zod.ZodString, zod.ZodString>>;
        devDependencies: zod.ZodOptional<zod.ZodRecord<zod.ZodString, zod.ZodString>>;
        peerDependencies: zod.ZodOptional<zod.ZodRecord<zod.ZodString, zod.ZodString>>;
        peerDependenciesMeta: zod.ZodOptional<zod.ZodRecord<zod.ZodString, zod.ZodUnknown>>;
        scripts: zod.ZodOptional<zod.ZodRecord<zod.ZodString, zod.ZodString>>;
    }, "strip", zod.ZodTypeAny, {
        dependencies?: Record<string, string> | undefined;
        devDependencies?: Record<string, string> | undefined;
        peerDependencies?: Record<string, string> | undefined;
        peerDependenciesMeta?: Record<string, unknown> | undefined;
        scripts?: Record<string, string> | undefined;
    }, {
        dependencies?: Record<string, string> | undefined;
        devDependencies?: Record<string, string> | undefined;
        peerDependencies?: Record<string, string> | undefined;
        peerDependenciesMeta?: Record<string, unknown> | undefined;
        scripts?: Record<string, string> | undefined;
    }>>;
    pnpm: zod.ZodOptional<zod.ZodString>;
    repository: zod.ZodString;
    rulesetId: zod.ZodOptional<zod.ZodString>;
    title: zod.ZodString;
    type: zod.ZodOptional<zod.ZodUnion<[zod.ZodLiteral<"commonjs">, zod.ZodLiteral<"module">]>>;
    version: zod.ZodOptional<zod.ZodString>;
    words: zod.ZodOptional<zod.ZodArray<zod.ZodString, "many">>;
    workflowsVersions: zod.ZodOptional<zod.ZodRecord<zod.ZodString, zod.ZodRecord<zod.ZodString, zod.ZodObject<{
        hash: zod.ZodOptional<zod.ZodString>;
        pinned: zod.ZodOptional<zod.ZodBoolean>;
    }, "strip", zod.ZodTypeAny, {
        pinned?: boolean | undefined;
        hash?: string | undefined;
    }, {
        pinned?: boolean | undefined;
        hash?: string | undefined;
    }>>>>;
}>;

export { presetEverything };
